@@ -34,33 +34,41 @@ key.add_alias("alias/bar")
 To use a KMS key in a different stack in the same CDK application,
 pass the construct to the other stack:
 
-```python
-# Example may have issues. See https://github.com/aws/jsii/issues/826
+```ts lit=test/integ.key-sharing.lit.ts
 
-#
-# Stack that defines the key
-#
-class KeyStack(cdk.Stack):
+/**
+ * Stack that defines the key
+ */
+class KeyStack extends cdk.Stack {
+  public readonly key: kms.Key;
 
-    def __init__(self, scope, id, props=None):
-        super().__init__(scope, id, props)
-        self.key = kms.Key(self, "MyKey", removal_policy=RemovalPolicy.DESTROY)
+  constructor(scope: cdk.App, id: string, props?: cdk.StackProps) {
+    super(scope, id, props);
+    this.key = new kms.Key(this, 'MyKey', { removalPolicy: RemovalPolicy.DESTROY });
+  }
+}
 
-#
-# Stack that uses the key
-#
-class UseStack(cdk.Stack):
-    def __init__(self, scope, id, *, key):
-        super().__init__(scope, id, key=key)
+interface UseStackProps extends cdk.StackProps {
+  key: kms.IKey; // Use IKey here
+}
 
-        # Use the IKey object here.
-        kms.Alias(self, "Alias",
-            alias_name="alias/foo",
-            target_key=key
-        )
+/**
+ * Stack that uses the key
+ */
+class UseStack extends cdk.Stack {
+  constructor(scope: cdk.App, id: string, props: UseStackProps) {
+    super(scope, id, props);
 
-key_stack = KeyStack(app, "KeyStack")
-UseStack(app, "UseStack", key=key_stack.key)
+    // Use the IKey object here.
+    new kms.Alias(this, 'Alias', {
+      aliasName: 'alias/foo',
+      targetKey: props.key
+    });
+  }
+}
+
+const keyStack = new KeyStack(app, 'KeyStack');
+new UseStack(app, 'UseStack', { key: keyStack.key });
 ```
 
 ### Importing existing keys
@@ -93,7 +101,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.16.3", __name__, "aws-kms@1.16.3.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.17.0", __name__, "aws-kms@1.17.0.jsii.tgz")
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'alias_target_key': 'aliasTargetKey'})
 class AliasAttributes():
     def __init__(self, *, alias_name: str, alias_target_key: "IKey"):
